==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/pages_8.js <==
var searchData=
[
  ['batchcg_20in_20ginkgo_0',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
  ['batched_20linear_20operator_20as_20a_20concept_1',['Batched Linear operator as a concept',['../group__BatchLinOp.html#batch_linop_concept',1,'']]],
  ['batched_20solver_20program_2',['The batched-solver program',['../batched_solver.html',1,'']]],
  ['benchmark_20options_3',['7: Available benchmark options',['../benchmarking_ginkgo.html#autotoc_md17',1,'']]],
  ['benchmarking_20overview_4',['4: Benchmarking overview',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['benchmarks_5',['Running the benchmarks',['../benchmarking_ginkgo.html',1,'']]],
  ['benchmarks_20manually_6',['3: Running benchmarks manually',['../benchmarking_ginkgo.html#autotoc_md13',1,'']]],
  ['best_20practice_20guidelines_7',['1: Ginkgo setup and best practice guidelines',['../benchmarking_ginkgo.html#autotoc_md11',1,'']]],
  ['blockjacobi_20program_8',['The adaptiveprecision-blockjacobi program',['../adaptiveprecision_blockjacobi.html',1,'']]],
  ['building_9',['Building',['../install_ginkgo.html#autotoc_md0',1,'']]],
  ['building_20ginkgo_20in_20windows_10',['Building Ginkgo in Windows',['../install_ginkgo.html#autotoc_md1',1,'']]],
  ['building_20ginkgo_20with_20hip_20support_11',['Building Ginkgo with HIP support',['../install_ginkgo.html#autotoc_md2',1,'']]],
  ['by_20clangformat_12',['Other Code Formatting not handled by ClangFormat',['../contributing_guidelines.html#autotoc_md44',1,'']]]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/pages_8.js <==
var searchData=
[
  ['batchcg_20in_20ginkgo_0',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
  ['batched_20linear_20operator_20as_20a_20concept_1',['Batched Linear operator as a concept',['../group__BatchLinOp.html#batch_linop_concept',1,'']]],
  ['benchmark_20options_2',['7: Available benchmark options',['../benchmarking_ginkgo.html#autotoc_md17',1,'']]],
  ['benchmark_20or_20run_5fall_5fbenchmarks_20sh_3',['4: Benchmarking with &lt;span class=&quot;tt&quot;&gt;make benchmark&lt;/span&gt; or &lt;span class=&quot;tt&quot;&gt;run_all_benchmarks.sh&lt;/span&gt;',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['benchmarking_20with_20make_20benchmark_20or_20run_5fall_5fbenchmarks_20sh_4',['4: Benchmarking with &lt;span class=&quot;tt&quot;&gt;make benchmark&lt;/span&gt; or &lt;span class=&quot;tt&quot;&gt;run_all_benchmarks.sh&lt;/span&gt;',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['benchmarks_5',['Running the benchmarks',['../benchmarking_ginkgo.html',1,'']]],
  ['benchmarks_20manually_6',['3: Running benchmarks manually',['../benchmarking_ginkgo.html#autotoc_md13',1,'']]],
  ['best_20practice_20guidelines_7',['1: Ginkgo setup and best practice guidelines',['../benchmarking_ginkgo.html#autotoc_md11',1,'']]],
  ['blockjacobi_20program_8',['The adaptiveprecision-blockjacobi program',['../adaptiveprecision_blockjacobi.html',1,'']]],
  ['building_9',['Building',['../install_ginkgo.html#autotoc_md0',1,'']]],
  ['building_20ginkgo_20in_20windows_10',['Building Ginkgo in Windows',['../install_ginkgo.html#autotoc_md1',1,'']]],
  ['building_20ginkgo_20with_20hip_20support_11',['Building Ginkgo with HIP support',['../install_ginkgo.html#autotoc_md2',1,'']]],
  ['by_20clangformat_12',['Other Code Formatting not handled by ClangFormat',['../contributing_guidelines.html#autotoc_md44',1,'']]]
];
